@@ -154,8 +154,7 @@ pub fn solve(
         (2018, 1, _) => to_stringer_input(year2018::day01::solve, &mut input),
         (2018, 2, 1) => to_stringer(year2018::day02::part1, input_string),
         (2018, 2, 2) => to_stringer(year2018::day02::part2, input_string),
-        (2018, 3, 1) => to_stringer(year2018::day03::part1, input_string),
-        (2018, 3, 2) => to_stringer(year2018::day03::part2, input_string),
+        (2018, 3, _) => to_stringer_input(year2018::day03::solve, &mut input),
         (2018, 4, 1) => to_stringer(year2018::day04::part1, input_string),
         (2018, 4, 2) => to_stringer(year2018::day04::part2, input_string),
         (2018, 5, 1) => to_stringer(year2018::day05::part1, input_string),
@@ -166,8 +165,7 @@ pub fn solve(
         (2018, 7, 2) => to_stringer(year2018::day07::part2, input_string),
         (2018, 8, 1) => to_stringer(year2018::day08::part1, input_string),
         (2018, 8, 2) => to_stringer(year2018::day08::part2, input_string),
-        (2018, 9, 1) => to_stringer(year2018::day09::part1, input_string),
-        (2018, 9, 2) => to_stringer(year2018::day09::part2, input_string),
+        (2018, 9, _) => to_stringer_input(year2018::day09::solve, &mut input),
         (2018, 10, 1) => to_stringer(year2018::day10::part1, input_string),
         (2018, 10, 2) => to_stringer(year2018::day10::part2, input_string),
         (2018, 11, 1) => to_stringer(year2018::day11::part1, input_string),
@@ -182,8 +180,7 @@ pub fn solve(
         (2018, 15, 2) => to_stringer(year2018::day15::part2, input_string),
         (2018, 16, 1) => to_stringer(year2018::day16::part1, input_string),
         (2018, 16, 2) => to_stringer(year2018::day16::part2, input_string),
-        (2018, 17, 1) => to_stringer(year2018::day17::part1, input_string),
-        (2018, 17, 2) => to_stringer(year2018::day17::part2, input_string),
+        (2018, 17, _) => to_stringer_input(year2018::day17::solve, &mut input),
         (2018, 18, 1) => to_stringer(year2018::day18::part1, input_string),
         (2018, 18, 2) => to_stringer(year2018::day18::part2, input_string),
         (2018, 19, 1) => to_stringer(year2018::day19::part1, input_string),
@@ -230,8 +227,7 @@ pub fn solve(
         (2019, 17, 2) => to_stringer(year2019::day17::part2, input_string),
         (2019, 18, _) => to_stringer_input(year2019::day18::solve, &mut input),
         (2019, 19, _) => to_stringer_input(year2019::day19::solve, &mut input),
-        (2019, 20, 1) => to_stringer(year2019::day20::part1, input_string),
-        (2019, 20, 2) => to_stringer(year2019::day20::part2, input_string),
+        (2019, 20, _) => to_stringer_input(year2019::day20::solve, &mut input),
         (2019, 21, 1) => to_stringer(year2019::day21::part1, input_string),
         (2019, 21, 2) => to_stringer(year2019::day21::part2, input_string),
         (2019, 22, 1) => to_stringer(year2019::day22::part1, input_string),
